@@ -23,6 +23,15 @@ FAILEDOPERATION = 'FailedOperation'
 # 操作访问密钥错误。
 FAILEDOPERATION_ACCESSKEY = 'FailedOperation.Accesskey'
 
+# 生成AuthToken异常。
+FAILEDOPERATION_BUILDAUTHTOKEN = 'FailedOperation.BuildAuthToken'
+
+# 凭据操作失败。
+FAILEDOPERATION_FLOWAUTHILLEGAL = 'FailedOperation.FlowAuthIllegal'
+
+# 集团策略不允许操作。
+FAILEDOPERATION_ORGANIZATIONPOLICYOPERATEERROR = 'FailedOperation.OrganizationPolicyOperateError'
+
 # 用户策略数超过上限。
 FAILEDOPERATION_POLICYFULL = 'FailedOperation.PolicyFull'
 
@@ -134,6 +143,9 @@ INVALIDPARAMETER_NOTSUPPORTPRODUCT = 'InvalidParameter.NotSupportProduct'
 # 一次操作实体数过多。
 INVALIDPARAMETER_OPERATEENTITIESOVERLIMIT = 'InvalidParameter.OperateEntitiesOverLimit'
 
+# 一次操作策略数过多。
+INVALIDPARAMETER_OPERATEPOLICIESOVERLIMIT = 'InvalidParameter.OperatePoliciesOverLimit'
+
 # 当前角色仅支持企业管理员操作，如需修改，请联系企业管理员。
 INVALIDPARAMETER_ORGANIZATIONROLEOPERATEERROR = 'InvalidParameter.OrganizationRoleOperateError'
 
@@ -299,6 +311,9 @@ REQUESTLIMITEXCEEDED_CREATEUSER = 'RequestLimitExceeded.CreateUser'
 # 用户账号超出了限制。
 REQUESTLIMITEXCEEDED_UINLIMITEXCEEDED = 'RequestLimitExceeded.UinLimitExceeded'
 
+# 未开启CAM数据流认证。
+RESOURCENOTFOUND_DATAFLOWAUTHCLOSE = 'ResourceNotFound.DataFlowAuthClose'
+
 # 用户组不存在。
 RESOURCENOTFOUND_GROUPNOTEXIST = 'ResourceNotFound.GroupNotExist'
 
@@ -317,6 +332,9 @@ RESOURCENOTFOUND_SECRETNOTEXIST = 'ResourceNotFound.SecretNotExist'
 # 用户不存在。
 RESOURCENOTFOUND_USERNOTEXIST = 'ResourceNotFound.UserNotExist'
 
+# 凭据信息异常。
+RESOURCEUNAVAILABLE_FLOWAUTHSECET = 'ResourceUnavailable.FlowAuthSecet'
+
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
